import { DescribeResourceTypeOptions } from './cfn-registry';
import { DescribeProductAggregateOptions } from './service-catalog';
import { TypeInfo } from './type-info';
export interface ImportResourceTypeOptions extends DescribeResourceTypeOptions {
    /**
     * @default "."
     */
    readonly outdir?: string;
}
/**
 * Load the resource definition from the CFN registry
 */
export declare function readResourceDefinitionFromRegistry(resourceName: string, _resourceVersion: string, options?: DescribeResourceTypeOptions): Promise<TypeInfo>;
/**
 * Entry point to import CFN resource types
 *
 * @param typeInfo the schema and metadata information for the type
 * @param options options for code generation
 * @returns name of the resource type
 */
export declare function importResourceType(typeInfo: TypeInfo, options: ImportResourceTypeOptions): string;
/**
 * Configure options for importing products into your local workspace
 */
export interface ImportProductOptions extends DescribeProductAggregateOptions {
    /**
     * The folder in which product constructs (as separate class files) will be output to.
     * @default "./sc-products"
     */
    readonly outdir?: string;
}
/**
 * Entry point to import Service Catalog product resource.
 *
 * @returns name of the product version
 */
export declare function importProduct(options: ImportProductOptions): Promise<string>;
/**
 * Entry point to import all available Service Catalog product resources with `DEFAULT` parameters.
 *
 * @returns names of the product versions
 */
export declare function importProducts(options: ImportProductOptions): Promise<string[]>;
